@@ -28,9 +28,15 @@
 #ifndef RMATH_H
 #define RMATH_H
 
+#ifdef  __cplusplus
+extern "C" {
+#endif
+
 /*-- Mathlib as part of R --  define this for standalone : */
 /* #undef MATHLIB_STANDALONE */
 
+#define R_VERSION_STRING "2.1.1"
+
 #ifndef HAVE_LOG1P
 # define HAVE_LOG1P 1
 #endif
@@ -40,7 +46,7 @@
 #endif
 
 #ifndef HAVE_WORKING_LOG1P
-# undef HAVE_WORKING_LOG1P
+# define HAVE_WORKING_LOG1P 1
 #endif
 
 #include <errno.h>
@@ -172,6 +178,7 @@ double  Rlog1p(double);
 #define M_LN_SQRT_PId2	0.225791352644727432363097614947	/* log(sqrt(pi/2)) */
 #endif
 
+
 #ifdef MATHLIB_STANDALONE
  #undef FALSE
  #undef TRUE
@@ -181,7 +188,6 @@ double  Rlog1p(double);
 #endif
 
 
-
 #ifndef MATHLIB_STANDALONE
 #define bessel_i	Rf_bessel_i
 #define bessel_j	Rf_bessel_j
@@ -227,6 +233,10 @@ double  Rlog1p(double);
 #define lbeta		Rf_lbeta
 #define lchoose		Rf_lchoose
 #define lgammafn	Rf_lgammafn
+#define lgamma1p	Rf_lgamma1p
+#define log1pmx		Rf_log1pmx
+#define logspace_add	Rf_logspace_add
+#define logspace_sub	Rf_logspace_sub
 #define pbeta		Rf_pbeta
 #define pbeta_raw	Rf_pbeta_raw
 #define pbinom		Rf_pbinom
@@ -315,9 +325,9 @@ double  Rlog1p(double);
 #undef trunc
 #define	trunc	ftrunc
 
-#ifdef  __cplusplus
-extern "C" {
-#endif
+
+/* log(1 - exp(x))  in stable form: */
+#define R_Log1_Exp(x)   ((x) > -M_LN2 ? log(-expm1(x)) : log1p(-exp(x)))
 
 	/* R's versions with !R_FINITE checks */
 
@@ -361,6 +371,11 @@ double	pgamma(double, double, double, int, int);
 double	qgamma(double, double, double, int, int);
 double	rgamma(double, double);
 
+double  log1pmx(double);
+double  lgamma1p(double);
+double  logspace_add(double, double);
+double  logspace_sub(double, double);
+
 	/* Beta Distribution */
 
 double	dbeta(double, double, double, int);
@@ -552,6 +567,21 @@ double	fround(double, double);
 double	fsign(double, double);
 double	ftrunc(double);
 
+double  log1pmx(double); /* Accurate log(1+x) - x, {care for small x} */
+double  lgamma1p(double);/* accurate log(gamma(x+1)), small x (0 < x < 0.5) */
+
+/* Compute the log of a sum or difference from logs of terms, i.e.,
+ *
+ *     log (exp (logx) + exp (logy))
+ * or  log (exp (logx) - exp (logy))
+ *
+ * without causing overflows or throwing away too much accuracy:
+ */
+double  logspace_add(double logx, double logy);
+double  logspace_sub(double logx, double logy);
+
+
+
 
 /* ----------------- Private part of the header file ------------------- */
 
@@ -573,16 +603,21 @@ double	gamma_cody(double);
 #ifdef MATHLIB_STANDALONE
 #ifndef MATHLIB_PRIVATE_H
 
-#ifdef IEEE_754
-# define ISNAN(x) (isnan(x)!=0)
+/* If isnan is a macro, as C99 specifies, the C++
+   math header will undefine it. This happens on OS X */
+#ifdef __cplusplus
+  int R_isnancpp(double); /* in mlutils.c */
+#  define ISNAN(x)     R_isnancpp(x)
 #else
-# define ISNAN(x)      R_IsNaNorNA(x)
+#  define ISNAN(x)     (isnan(x)!=0)
 #endif
+
+
+/* We don't have config information available to do anything else */
 #define R_FINITE(x)    R_finite(x)
-int R_IsNaNorNA(double);
 int R_finite(double);
 
-#ifdef WIN32
+#ifdef WIN32  /* not Win32 as no config information */
 # define NA_REAL (*_imp__NA_REAL)
 # define R_NegInf (*_imp__R_NegInf)
 # define R_PosInf (*_imp__R_PosInf)
