@@ -1,6 +1,6 @@
 ### Name: Random
 ### Title: Random Number Generation
-### Aliases: .Random.seed RNG RNGkind RNGversion set.seed
+### Aliases: RNG RNGkind RNGversion set.seed .Random.seed
 ### Keywords: distribution sysdata
 
 ### ** Examples
@@ -39,5 +39,10 @@ RNGkind()
 ## Reset:
 RNGkind(ok[1])
 
+## ----
+sum(duplicated(runif(1e6))) # around 110
+## and we would expect about almost sure duplicates beyond about
+qbirthday(1-1e-6, classes=2e9) # 235,000
+
 
 
