@@ -1,6 +1,6 @@
 ### Name: autoload
 ### Title: On-demand Loading of Packages
-### Aliases: autoload autoloader .AutoloadEnv
+### Aliases: autoload autoloader .AutoloadEnv .Autoloaded Autoloads
 ### Keywords: data programming
 
 ### ** Examples
@@ -9,6 +9,7 @@ require(stats)
 autoload("interpSpline", "splines")
 search()
 ls("Autoloads")
+.Autoloaded
 
 x <- sort(rnorm(12))
 y <- x^2
