@@ -30,8 +30,15 @@ y <- rnorm(100)
 table(cut(y, breaks = pi/3*(-3:3)))
 table(cut(y, breaks = pi/3*(-3:3), dig.lab=4))
 
-table(cut(y, breaks =  1*(-3:3), dig.lab=4))# extra digits don't "harm" here
-table(cut(y, breaks =  1*(-3:3), right = FALSE))#- the same, since no exact INT!
+table(cut(y, breaks =  1*(-3:3), dig.lab=4))
+# extra digits don't "harm" here
+table(cut(y, breaks =  1*(-3:3), right = FALSE))
+#- the same, since no exact INT!
+
+## sometimes the default dig.lab is not enough to be avoid confusion:
+aaa <- c(1,2,3,4,5,2,3,4,5,6,7)
+cut(aaa, 3)
+cut(aaa, 3, dig.lab=4)
 
 
 
