@@ -10,6 +10,15 @@ dput(mean, "foo")
 ## And read it back into 'bar'
 bar <- dget("foo")
 unlink("foo")
+## Create a function with comments
+baz <- function(x) {
+  # Subtract from one
+  1-x
+}
+## and display it
+dput(baz)
+## and now display the saved source
+dput(baz, control = "useSource")
 
 
 
