@@ -5,7 +5,7 @@
 
 ### ** Examples
 
-is.loaded(symbol.For("hcass2")) #-> probably TRUE, as stats is loaded
+is.loaded("hcass2") #-> probably TRUE, as stats is loaded
 
 
 
