@@ -15,12 +15,14 @@ ls(envir=environment(approxfun(1:2,1:2, method="const")))
 
 is.environment(.GlobalEnv) # TRUE
 
-e1 <- new.env(TRUE, NULL)  # these two have parent package:base.
-e2 <- new.env(FALSE, NULL)
-assign("a", 3, env=e2)
-parent.env(e1) <- e2
-get("a", env=e1)
-
+e1 <- new.env(parent = NULL)  # this one has enclosure package:base.
+e2 <- new.env(parent = e1)
+assign("a", 3, env=e1)
+ls(e1)
+ls(e2)
+exists("a", env=e2)     # this succeeds by inheritance     
+exists("a", env=e2, inherits = FALSE)
+exists("+", env=e2)     # this succeeds by inheritance
 
 
 
