@@ -5,9 +5,11 @@
 
 ### ** Examples
 
-a <- gl(2, 2, 8)
-b <- gl(2, 4, 8)
+a <- gl(2, 4, 8)
+b <- gl(2, 2, 8, label = c("ctrl", "treat"))
+s <- gl(2, 1, 8, label = c("M", "F"))
 interaction(a, b)
+interaction(a, b, s, sep = ":")
 
 
 
