@@ -1,12 +1,12 @@
 ### Name: load
 ### Title: Reload Saved Datasets
-### Aliases: load loadURL
+### Aliases: load
 ### Keywords: file
 
 ### ** Examples
 
 ## save all data
-save(list = ls(), file= "all.Rdata")
+save(list = ls(all=TRUE), file= "all.Rdata")
 
 ## restore the saved values to the current environment
 load("all.Rdata")
@@ -15,10 +15,7 @@ load("all.Rdata")
 load("all.Rdata", .GlobalEnv)
 
 ## Not run: 
-##D ## This example is not real
 ##D ## print the value to see what objects were created.
-##D print(loadURL("http://some.where.net/R/data/kprats.rda"))
-##D # or, avoiding making a local copy,
 ##D print(load(url("http://some.where.net/R/data/kprats.rda")))
 ## End(Not run)
 
