@@ -7,10 +7,14 @@
 ### ** Examples
 
 is.matrix(as.matrix(1:10))
-data(warpbreaks)
 !is.matrix(warpbreaks)# data.frame, NOT matrix!
 warpbreaks[1:10,]
 as.matrix(warpbreaks[1:10,]) #using as.matrix.data.frame(.) method
 
+# Example of setting row and column names
+mdat <- matrix(c(1,2,3, 11,12,13), nrow = 2, ncol=3, byrow=TRUE,
+               dimnames = list(c("row1", "row2"), c("C.1", "C.2", "C.3")))
+mdat
+
 
 
