@@ -5,12 +5,13 @@
 
 ### ** Examples
 
-data(islands)
 # print the names attribute of the islands data set
 names(islands)
 
 # remove the names attribute
 names(islands) <- NULL
+islands
+rm(islands) # remove the copy made
 
 z <- list(a=1, b="c", c=1:3)
 names(z)
