@@ -11,10 +11,9 @@ rr <- for(i in 1:3) print(1:i)
 rr
 
 ## Printing of factors
-data(attenu)
 attenu$station ## 117 levels -> `max.levels' depending on width
 
-data(esoph) ## ordered : levels  "l1 < l2 < .."
+## ordered factors: levels  "l1 < l2 < .."
 esoph$agegp[1:12]
 esoph$alcgp[1:12]
 
