@@ -12,5 +12,11 @@ seq(as.Date("2000/1/1"), by="month", length=12)
 ## quarters
 seq(as.Date("2000/1/1"), as.Date("2003/1/1"), by="3 months")
 
+## find all 7th of the month between two dates, the last being a 7th.
+st <- as.Date("1998-12-17")
+en <- as.Date("2000-1-7")
+ll <- seq.Date(en, st, by="-1 month")
+rev(ll[ll > st & ll < en])
+
 
 
