@@ -6,6 +6,8 @@
 
 ### ** Examples
 
+## Note: the first two examples will give different results
+## if run by example().
 ff <- function(x) gg(x)
 gg <- function(y) sys.status()
 str(ff(1))
@@ -27,7 +29,7 @@ t1 <- function() {
     ## in frame 2 here
     cat("current frame is", sys.nframe(), "\n")
     str(sys.calls()) ## list with two components t1() and t2()
-    cat("parents are frame nos", sys.parents(), "\n") ## 0 1
+    cat("parents are frame numbers", sys.parents(), "\n") ## 0 1
     print(ls(envir=sys.frame(-1))) ## [1] "aa" "t2"
     invisible()
   }
@@ -44,5 +46,19 @@ test.sys.on.exit <- function() {
 test.sys.on.exit()
 ## gives 'language print(1)', prints 1 on exit
 
+## An example where the parent is not the next frame up the stack
+## since method dispatch uses a frame.
+as.double.foo <- function(x)
+{
+    str(sys.calls())
+    print(sys.frames())
+    print(sys.parents())
+    print(sys.frame(-1)); print(parent.frame())
+    x
+}
+t2 <- function(x) as.double(x)
+a <- structure(pi, class = "foo")
+t2(a)
+
 
 
