@@ -5,16 +5,20 @@
 
 ### ** Examples
 
-## generate 25 objects, divided into two clusters, and 3 objects lying
+## generate 10+15 objects in two clusters, plus 3 objects lying
 ## between those clusters.
 x <- rbind(cbind(rnorm(10, 0, 0.5), rnorm(10, 0, 0.5)),
            cbind(rnorm(15, 5, 0.5), rnorm(15, 5, 0.5)),
-           cbind(rnorm( 3,3.5,0.5), rnorm( 3,3.5,0.5)))
+           cbind(rnorm( 3,3.2,0.5), rnorm( 3,3.2,0.5)))
 fannyx <- fanny(x, 2)
+## Note that observations 26:28 are "fuzzy" (closer to # 2):
 fannyx
 summary(fannyx)
 plot(fannyx)
 
+(fan.x.15 <- fanny(x, 2, memb.exp = 1.5)) # 'crispier' for obs. 26:28
+(fanny(x, 2, memb.exp = 3))               # more fuzzy in general
+
 data(ruspini)
 ## Plot similar to Figure 6 in Stryuf et al (1996)
 plot(fanny(ruspini, 5))
