@@ -12,11 +12,16 @@ image(z, axes = FALSE, main = "Math can be beautiful ...",
       xlab = expression(cos(r^2) * e^{-r/6}))
 contour(z, add = TRUE, drawlabels = FALSE)
 
-data(volcano)
+# Volcano data visualized as matrix. Need to transpose and flip
+# matrix horizontally. 
+image(t(volcano)[ncol(volcano):1,])
+
+# A prettier display of the volcano
 x <- 10*(1:nrow(volcano))
 y <- 10*(1:ncol(volcano))
 image(x, y, volcano, col = terrain.colors(100), axes = FALSE)
-contour(x, y, volcano, levels = seq(90, 200, by=5), add = TRUE, col = "peru")
+contour(x, y, volcano, levels = seq(90, 200, by = 5),
+        add = TRUE, col = "peru")
 axis(1, at = seq(100, 800, by = 100))
 axis(2, at = seq(100, 600, by = 100))
 box()
