@@ -1,5 +1,6 @@
 ### Name: symbols
-### Title: Draw symbols on a plot
+### Title: Draw Symbols (Circles, Squares, Stars, Thermometers, Boxplots)
+###   on a Plot
 ### Aliases: symbols
 ### Keywords: aplot hplot multivariate
 
@@ -14,7 +15,6 @@ symbols(x, y, thermometers = z3, inches=FALSE)
 text(x,y, apply(format(round(z3, dig=2)), 1, paste, collapse = ","),
      adj = c(-.2,0), cex = .75, col = "purple", xpd=NA)
 
-data(trees)
 ## Note that  example(trees)  shows more sensible plots!
 N <- nrow(trees)
 attach(trees)
