@@ -5,8 +5,8 @@
 
 ### ** Examples
 
-xy.coords(fft(c(1:10)), NULL)
-data(cars)
+xy.coords(stats::fft(c(1:10)), NULL)
+
 with(cars, xy.coords(dist ~ speed, NULL)$xlab ) # = "speed"
 
 xy.coords(1:3, 1:2, recycle=TRUE)
