@@ -5,7 +5,7 @@
 
 ### ** Examples
 
-data(volcano)  ## 87 x 61 matrix
+## volcano  ## 87 x 61 matrix
 wireframe(volcano, shade = TRUE,
           aspect = c(61/87, 0.4),
           light.source = c(10,0,10))
@@ -14,18 +14,17 @@ g <- expand.grid(x = 1:10, y = 5:15, gr = 1:2)
 g$z <- log((g$x^g$g + g$y^2) * g$gr)
 wireframe(z ~ x * y, data = g, groups = gr,
           scales = list(arrows = FALSE),
-          drape = TRUE,
+          drape = TRUE, colorkey = TRUE,
           screen = list(z = 30, x = -60))
 
-data(iris)
 cloud(Sepal.Length ~ Petal.Length * Petal.Width | Species, data = iris,
       screen = list(x = -90, y = 70), distance = .4, zoom = .6)
 
-par.set <- list(axis.line = list(col = "transparent"), clip = list(panel = FALSE))
+par.set <-
+    list(axis.line = list(col = "transparent"), clip = list(panel = FALSE))
 print(cloud(Sepal.Length ~ Petal.Length * Petal.Width, 
             data = iris, cex = .8, 
             groups = Species, 
-            subpanel = panel.superpose,
             main = "Stereo",
             screen = list(z = 20, x = -70, y = 3),
             par.settings = par.set),
@@ -33,7 +32,6 @@ print(cloud(Sepal.Length ~ Petal.Length * Petal.Width,
 print(cloud(Sepal.Length ~ Petal.Length * Petal.Width,
             data = iris, cex = .8, 
             groups = Species,
-            subpanel = panel.superpose,
             main = "Stereo",
             screen = list(z = 20, x = -70, y = 0),
             par.settings = par.set),
