@@ -1,13 +1,11 @@
 ### Name: histogram
 ### Title: Histograms and Kernel Density Plots
-### Aliases: histogram densityplot
+### Aliases: histogram densityplot do.breaks
 ### Keywords: hplot
 
 ### ** Examples
 
 require(stats)
-data(singer)
-
 histogram( ~ height | voice.part, data = singer, nint = 17,
           endpoints = c(59.5, 76.5), layout = c(2,4), aspect = 1,
           xlab = "Height (inches)")
