@@ -19,12 +19,12 @@ hasMethod("testFun") # default method
 hasMethod("testFun", "ANY")
 ## Not run: [1] FALSE
 ## Don't show: 
-stopifnot(isGeneric("testFun"))
-stopifnot(hasMethod("testFun", "numeric"))
-stopifnot(hasMethod("testFun", "integer"))
-stopifnot(!existsMethod("testFun", "integer"))
-stopifnot(!hasMethod("testFun"))
-stopifnot(!hasMethod("testFun", "ANY"))
+stopifnot(isGeneric("testFun"),
+          hasMethod("testFun", "numeric"),
+          hasMethod("testFun", "integer"),
+          !existsMethod("testFun", "integer"),
+          !hasMethod("testFun"),
+          !hasMethod("testFun", "ANY") )
 removeGeneric("testFun")
 ## End Don't show
 
