@@ -1,11 +1,10 @@
 ### Name: bs
-### Title: Generate a Basis for Polynomial Splines
+### Title: B-Spline Basis for Polynomial Splines
 ### Aliases: bs
 ### Keywords: smooth
 
 ### ** Examples
 
-data(women)
 bs(women$height, df = 5)
 summary(fm1 <- lm(weight ~ bs(height, df = 5), data = women))
 
