@@ -1,12 +1,11 @@
 ### Name: predict.bSpline
-### Title: Evaluate a spline at new values of x
+### Title: Evaluate a Spline at New Values of x
 ### Aliases: predict.bSpline predict.nbSpline predict.pbSpline
 ###   predict.npolySpline predict.ppolySpline
 ### Keywords: models
 
 ### ** Examples
 
-data( women )
 ispl <- interpSpline( weight ~ height,  women )
 opar <- par(mfrow = c(2, 2), las = 1)
 plot(predict(ispl, nseg = 201),     # plots over the range of the knots
