@@ -7,18 +7,20 @@
 
 ## see also JohnsonJohnson, Nile and AirPassengers
 
-data(treering)
 trees <- window(treering, start=0)
 (fit <- StructTS(trees, type = "level"))
 plot(trees)
 lines(fitted(fit), col = "green")
 tsdiag(fit)
 
-data(UKgas)
 (fit <- StructTS(log10(UKgas), type = "BSM"))
 par(mfrow = c(4, 1))
 plot(log10(UKgas))
 plot(cbind(fitted(fit), resids=resid(fit)), main = "UK gas consumption")
 
+## keep some parameters fixed; trace optimizer:
+StructTS(log10(UKgas), type = "BSM", fixed = c(0.1, 0.001,NA,NA),
+         optim.control = list(trace=TRUE))
+
 
 
