@@ -5,7 +5,7 @@
 
 ### ** Examples
 
-data(InsectSprays)              # Not really a good example
+## Not really a good example
 chisq.test(InsectSprays$count > 7, InsectSprays$spray)
                                 # Prints test summary
 chisq.test(InsectSprays$count > 7, InsectSprays$spray)$obs
@@ -24,6 +24,19 @@ chisq.test(x, simulate.p.value = TRUE, B = 10000)$p.value
 x <- c(A = 20, B = 15, C = 25)
 chisq.test(x)
 chisq.test(as.table(x))         # the same
+x <- c(89,37,30,28,2)
+p <- c(40,20,20,15,5)
+try(
+chisq.test(x, p = p)            # gives an error
+)
+chisq.test(x, p = p, rescale.p = TRUE)
+                                # works
+p <- c(0.40,0.20,0.20,0.19,0.01)
+                                # Expected count in category 5
+                                # is 1.86 < 5 ==> chi square approx.
+chisq.test(x, p = p)            #               maybe doubtful, but is ok!
+chisq.test(x, p = p,simulate.p.value = TRUE)
+
 ## Case B. Raw data
 x <- trunc(5 * runif(100))
 chisq.test(table(x))            # NOT 'chisq.test(x)'!
