@@ -13,7 +13,6 @@ var(1:5,1:5)# 2.5
 cor(1:10,2:11)# == 1
 
 ## Correlation Matrix of Multivariate sample:
-data(longley)
 (Cl <- cor(longley))
 ## Graphical Correlation Matrix:
 symnum(Cl) # highly correlated
@@ -33,7 +32,6 @@ stopifnot(all.equal(Cl, cov2cor(cov(longley))),
             cov2cor(cov(longley, method="kendall"))))
 
 ##--- Missing value treatment:
-data(swiss)
 C1 <- cov(swiss)
 range(eigen(C1, only=TRUE)$val) # 6.19  1921
 swM <- swiss
@@ -48,8 +46,5 @@ range(eigen(C3, only=TRUE)$val) # 6.19  1938
 ## Kendall's tau doesn't change much: identical symnum codings!
 identical(scM, symnum(cor(swiss, method = "kendall")))
 
-all.equal(cov2cor(cov(swM, method = "kendall", use = "pairwise")),
-                  cor(swM, method = "kendall", use = "pairwise"))
-
 
 
