@@ -1,7 +1,7 @@
 ### Name: dist
 ### Title: Distance Matrix Computation
-### Aliases: dist print.dist format.dist as.matrix.dist names.dist
-###   names<-.dist as.dist
+### Aliases: dist print.dist format.dist as.matrix.dist as.dist
+###   as.dist.default
 ### Keywords: multivariate cluster
 
 ### ** Examples
@@ -13,8 +13,6 @@ dist(x, upper = TRUE)
 m <- as.matrix(dist(x))
 d <- as.dist(m)
 stopifnot(d == dist(x))
-names(d) <- LETTERS[1:5]
-print(d, digits = 3)
 
 ## example of binary and canberra distances.
 x <- c(0, 0, 1, 1, 1, 1)
@@ -25,7 +23,6 @@ dist(rbind(x,y), method="canberra")
 ## answer 2 * (6/5)
 
 ## Examples involving "Inf" :
-## These will not work on a non-IEEE 754 system.
 ## 1)
 x[6] <- Inf
 (m2 <- rbind(x,y))
@@ -41,8 +38,8 @@ stopifnot(dist(cbind(x ,y), method="canberra") ==
 
 ## 2)
 y[6] <- Inf #-> 6-th pair is excluded
-dist(rbind(x,y), method="binary")# warning; 0.5
-dist(rbind(x,y), method="canberra")#  3
+dist(rbind(x,y), method="binary")   # warning; 0.5
+dist(rbind(x,y), method="canberra") # 3
 dist(rbind(x,y), method="maximum")  # 1
 dist(rbind(x,y), method="manhattan")# 2.4
 
