@@ -1,11 +1,10 @@
 ### Name: fligner.test
-### Title: Fligner-Killeen Test for Homogeneity of Variances
+### Title: Fligner-Killeen Test of Homogeneity of Variances
 ### Aliases: fligner.test fligner.test.default fligner.test.formula
 ### Keywords: htest
 
 ### ** Examples
 
-data(InsectSprays)
 plot(count ~ spray, data = InsectSprays)
 fligner.test(InsectSprays$count, InsectSprays$spray)
 fligner.test(count ~ spray, data = InsectSprays)
