@@ -1,6 +1,6 @@
 ### Name: kmeans
 ### Title: K-Means Clustering
-### Aliases: kmeans
+### Aliases: kmeans print.kmeans
 ### Keywords: multivariate cluster
 
 ### ** Examples
@@ -8,9 +8,15 @@
 # a 2-dimensional example
 x <- rbind(matrix(rnorm(100, sd = 0.3), ncol = 2),
            matrix(rnorm(100, mean = 1, sd = 0.3), ncol = 2))
-cl <- kmeans(x, 2, 20)
+colnames(x) <- c("x", "y")
+(cl <- kmeans(x, 2))
 plot(x, col = cl$cluster)
-points(cl$centers, col = 1:2, pch = 8)
+points(cl$centers, col = 1:2, pch = 8, cex=2)
+
+## random starts do help here with too many clusters
+(cl <- kmeans(x, 5, nstart = 25))
+plot(x, col = cl$cluster)
+points(cl$centers, col = 1:5, pch = 8)
 
 
 
