@@ -10,10 +10,12 @@
   hc <- hclust(dist(x))
   dd <- as.dendrogram(hc)
   dd.reorder <- reorder(dd, 10:1)
+  plot(dd, main = "random dendrogram `dd'")
 
   op <- par(mfcol = 1:2)
-  plot(dd, main = "random dendrogram `dd'")
   plot(dd.reorder, main = "reorder(dd, 10:1)")
+  plot(reorder(dd,10:1, agglo.FUN= mean),
+       main = "reorder(dd, 10:1, mean)")
   par(op)
 
 
