@@ -5,10 +5,8 @@
 
 ### ** Examples
 
-data(lh)
 spec.ar(lh)
 
-data(UKLungDeaths)
 spec.ar(ldeaths)
 spec.ar(ldeaths, method="burg")
 
