@@ -7,7 +7,6 @@
 
 ## reset contrasts to defaults
 options(contrasts=c("contr.treatment", "contr.poly"))
-data(warpbreaks)
 attach(warpbreaks)
 tens <- C(tension, poly, 1)
 attributes(tens)
@@ -18,7 +17,7 @@ aov(breaks ~ wool + tens + tension, data=warpbreaks)
 ## show the use of ...  The default contrast is contr.treatment here
 summary(lm(breaks ~ wool + C(tension, base=2), data=warpbreaks))
 
-data(esoph) # following on from help(esoph)
+# following on from help(esoph)
 model3 <- glm(cbind(ncases, ncontrols) ~ agegp + C(tobgp, , 1) +
      C(alcgp, , 1), data = esoph, family = binomial())
 summary(model3)
