@@ -5,7 +5,6 @@
 
 ### ** Examples
 
-data(aml)
 aml3<-survSplit(aml,cut=c(5,10,50),end="time",start="start",
       event="status",episode="i")
 
@@ -16,6 +15,9 @@ coxph(Surv(time,status)~x,data=aml)
 ## the same
 coxph(Surv(start,time,status)~x,data=aml3)
 
+aml4<-survSplit(aml3,cut=20,end="time",start="start", event="status")
+coxph(Surv(start,time,status)~x,data=aml4)
+
 
 
 
