@@ -5,18 +5,14 @@
 
 ### ** Examples
 
-## comparing data to population
-data(ratetables)        
-data(cancer)
 ## compare survival to US population
 cancer$year<-rep(as.date("1/1/1980"),nrow(cancer))
 efit <- survexp( ~ ratetable(sex=sex, year=year, age=age*365), times=(1:4)*365,data=cancer)
 plot(survfit(Surv(time, status) ~1,data=cancer))
 lines(efit)
-## compare data to Cox model
-## Mayo PBC data
-data(pbc)
-## fit to randomised patients
+
+## compare data to Cox model 
+## fit to randomised patients in Mayo PBC data
 m<-coxph(Surv(time,status)~edtrt+log(bili)+log(protime)+age+platelet,data=pbc,
       subset=trt>0)
 ##compare Kaplan-Meier to fitted model for 2 edema groups in
@@ -27,4 +23,3 @@ lines(survexp(~edtrt+ratetable(edtrt=edtrt,bili=bili,platelet=platelet,age=age,
 
 
 
-
